import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Table, Avatar, Radio, Modal, Descriptions } from 'antd';
import moment from 'moment';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import router from 'umi/router';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import AuthButton from '@/components/AuthButton';


const { Option } = Select;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const { Meta } = Card;

/**
 * 拼团者弹框
 */
class InviteTable extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      dataSource: { records: [] },
      visibleData: { visible: false, customerId: '', realtyConsultant: '' },
    }
  }

  // 挂载之后
  componentDidMount () {
    const { customerId } = this.state.visibleData
    this.getList({ helpRecordInitiateId: customerId, pageNumber: 1, pageSize: 5 })
  }

  componentDidUpdate (preProps, preState) {
    const { customerId } = this.state.visibleData
    if (this.props.visibleData.customerId !== preState.visibleData.customerId) {
      this.getList({ helpRecordInitiateId: customerId, pageNumber: 1, pageSize: 5 })
      this.setState({ visibleData: this.props.visibleData });
    }
  }

  // 弹框确定按钮
  // eslint-disable-next-line react/sort-comp
  handleOk () {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  // 弹框取消按钮
  handleCancel () {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  getList (params) {
    request({ ...apis.groupActivity.shareSuccList, params: { ...params } }).then(res => {
      this.setState({ dataSource: res })
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  // 分页
  onChange (pageNum) {
    this.getList({ pageNumber: pageNum, pageSize: 5 })
  }

  render () {
    const columns = [
      {
        title: '用户姓名',
        dataIndex: 'name',
        key: 'name',
        align: 'center',
      },
      {
        title: '手机号',
        dataIndex: 'phone',
        key: 'phone',
        align: 'center',
        render: text => <a>{text}</a>,
      },
      {
        title: '开团时间',
        dataIndex: 'createDate',
        key: 'createDate',
        align: 'center',
      },
    ]
    return (
      <>
        <Modal
          title="参团者"
          destroyOnClose="true"
          width={900}
          footer={null}
          visible={this.state.visibleData.visible}
          // onOk={() => this.handleOk()}
          onCancel={(e) => this.handleCancel(e)}
        >
          <Table rowKey="independent" dataSource={this.state.dataSource.records} columns={columns} pagination={{ total: this.state.dataSource.total, onChange: e => this.onChange(e) }} />
        </Modal>
      </>
    );
  }
}







/**
 * 拼团者弹框
 */
class Verifier extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      helpRecordInitiateId: { id: '' },
      visibleData: { visible: false, customerId: '', realtyConsultant: '', helpRecordInitiateId: '' },
    }
  }

  // 挂载之后
  componentDidMount () {
    const { customerId } = this.state.visibleData
    this.getList({ helpRecordInitiateId: customerId, pageNumber: 1, pageSize: 5 })
  }

  componentDidUpdate (preProps, preState) {
    const { customerId } = this.state.visibleData
    console.log('this.state.visibleData', this.state.visibleData)
    if (this.props.visibleData.customerId !== preState.visibleData.customerId) {
      this.getList({ helpRecordInitiateId: customerId, pageNumber: 1, pageSize: 5 })
      this.setState({ visibleData: this.props.visibleData });
    }
  }

  // 弹框确定按钮
  // eslint-disable-next-line react/sort-comp
  handleOk () {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  // 弹框取消按钮
  handleCancel () {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  getList (params) {
    request({ ...apis.groupActivity.shareSuccList, params: { ...params } }).then(res => {
        console.log(res);
      this.setState({ dataSource: res })
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  // eslint-disable-next-line class-methods-use-this
  verify(e) {
    console.log('111', e.target.value)
  }

  // eslint-disable-next-line class-methods-use-this
  verification(e) {
    console.log('this.state.visibleData', this.state.visibleData)
      alert(1)
  }

  render () {
    return (
      <>
        <Modal
          title="核销"
          destroyOnClose="true"
          width={300}
          footer={null}
          visible={this.state.visibleData.visible}
          // onOk={() => this.handleOk()}
          onCancel={(e) => this.handleCancel(e)}
        >
          <div><span>核销码:<input onChange={this.verify.bind(this)}/></span>
           <Button onClick={(e) => this.verification(e)}>立即核销</Button>
          </div>
        </Modal>
      </>
    );
  }
}

/**
 *主体列表
 *
 * @param {*} props
 * @returns
 */
function body(props) {
  const [gInviteData, setGInviteData] = useState({ visible: false, customerId: '', realtyConsultant: '' })

  const [gVerifierData, setVerifierData] = useState({ visible: false, customerId: '', realtyConsultant: '', helpRecordInitiateId: '' })

  const { getFieldDecorator, getFieldsValue } = props.form

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ records: [] })
  // eslint-disable-next-line react-hooks/rules-of-hooks
  // const [columns, setColumns] = useState(privateColumns)

  // 默认成功
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [groupStatus, setgroupStatus] = useState('0')

  // 调整归属 ============  start
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [gVisibleData, setGVisibleData] = useState({ visible: false, customerId: '', realtyConsultant: '' })


  // 变更状态 ============= end

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const { groupActivityId } = props.location.query
  useEffect(() => {
    getList({ pageNumber: 1, pageSize: 10, status: groupStatus, groupActivityId: groupActivityId })
  }, [])

  
  function getFailList(params) {
    // 网路请求
    request({ ...apis.groupActivity.shareFailList, params: { ...params } }).then(res => {
        console.log(res);
      setDataSource(res)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  function getList(params) {
    // 网路请求
    request({ ...apis.groupActivity.shareSuccList, params: { ...params } }).then(res => {
        console.log(res);
      setDataSource(res)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  function displayNone() {
    setGVisibleData({ visible: false, customerId: '', realtyConsultant: '' })
  }

  // 提交事件
  function handleSubmit(e) {
    displayNone()


    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        getList({ pageNum: 1, pageSize: 10, groupStatus, ...values })
      }
    });
  }

  // Change 事件
  function handleSelectChange(e) {
    // eslint-disable-next-line no-console
    console.log(e)
  }

  // 分页
  function onChange(pageNum) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    getList({ pageNumber: pageNum, pageSize: 10, groupStatus })
  }

  // 助力成功/进行中/助力失败
  function radioButtonHandleSizeChange(e) {
    setGInviteData({ visible: true, customerId: '', realtyConsultant: '' })
    displayNone()

    const { value } = e.target
    setgroupStatus(value)
    // setColumns(value === 'helpSucceed' ? privateColumns : publicColumns)
    if (value == 0) { 
        console.log("success", value)
        getList({ pageNumber: 1, pageSize: 10, status: value, groupActivityId }) }
    if (value == 1 || value == 2) {
        console.log("faile", value)
         getFailList({ pageNumber: 1, pageSize: 10, status: value, groupActivityId })
         }
  }

  function handleReset() {
    props.form.resetFields();
    getList({ pageNumber: 1, pageSize: 10, groupStatus })
  }

  function toCustomerDateil(record) {
    router.push({
      pathname: '/customer/customerlist/customerDetail',
      query: {
        id: record.customerId,
      },
    });
  }

  function exportCustomer () {
    const fieldsValue = getFieldsValue()
    request({ ...apis.customer.customerRecommendExport, responseType: 'blob', params: { ...fieldsValue, groupStatus } })
      .then(response => {
        download(response)
      }).catch(error => {

      })
  }

  function download (data) {
    if (!data) {
      return
    }
    const url = window.URL.createObjectURL(new Blob([data]))
    const link = document.createElement('a')
    link.style.display = 'none'
    link.href = url
    link.setAttribute('download', '客户列表.xlsx')
    document.body.append(link)
    link.click()
  }

// 助力记录弹框
function helpRecord(row) {
// 关闭核销
// eslint-disable-next-line max-len
setVerifierData({ visible: false, customerId: row.helpRecordInitiateId, realtyConsultant: row.realtyConsultant })
  // eslint-disable-next-line max-len
  setGInviteData({ visible: true, customerId: row.helpRecordInitiateId, realtyConsultant: row.realtyConsultant })
}
 // 核销
 function helpInitiateRecordVerify(row) {
// 关闭助力记录弹框
// eslint-disable-next-line max-len
  setVerifierData({ visible: true, customerId: row.helpRecordInitiateId, realtyConsultant: row.realtyConsultant })
  // eslint-disable-next-line max-len
  setGInviteData({ visible: false, customerId: row.helpRecordInitiateId, realtyConsultant: row.realtyConsultant })
 }

  const publicColumns = [
    {
      title: '拼团者',
      dataIndex: 'nickname',
      key: 'nickname',
      align: 'center',
      width: '15%',
    },
    {
      title: '拼团者手机号',
      dataIndex: 'phone',
      key: 'phone',
      align: 'center',
      width: '10%',
    },
    {
      title: '拼团时间',
      dataIndex: 'createTime',
      key: 'createTime',
      align: 'center',
      width: '15%',
    },
    {
      title: '参团者',
      dataIndex: 'helpCount',
      key: 'helpCount',
      align: 'center',
      width: '15%',
      render: (text, record) => <a style={ { color: '#66B3FF' } } onClick={() => helpRecord(record)}>{record.joinPeople}/{record.groupBuyPeople}</a>,
    },
  ]

  const privateColumns = [
    {
      title: '拼团者',
      dataIndex: 'nickname',
      key: 'nickname',
      align: 'center',
      width: '15%',
      // render: (_, record) => <Avatar shape="square" src={groupStatus === 'helpSucceed' ? record.picture : record.avatarurl} size={64} icon="user" />,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
      // render: (_, record) => <><span>{groupStatus === 'helpSucceed' ? record.name : record.nickname}</span></>,
    },
    {
      title: '发起时间',
      dataIndex: 'createTime',
      key: 'createTime',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
    },
    {
        title: '成团时间',
        dataIndex: 'endTime',
        key: 'endTime',
        align: 'center',
        width: '10%',
        // eslint-disable-next-line no-nested-ternary
    },
    {
      title: '核销状态',
      dataIndex: 'verificationStatus',
      key: 'verificationStatus',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
      render: (text, records) => {
        if (records.verificationStatus === 0) { return '未核销' }
        if (records.verificationStatus === 1) { return '已核销' }
      },
    },
    {
      title: '操作',
      dataIndex: 'customerId',
      key: 'customerId',
      align: 'center',
      width: '25%',
      render: (x, row) => (
        <>
          {row.verificationStatus === 0 &&
          <AuthButton name="admin.SignList.get" noRight={null}>
           <span style={{ color: '#1990FF', cursor: 'pointer' }} onClick={() => helpInitiateRecordVerify(row)}>核销</span>
          </AuthButton>
        }
        </>
      ),
    },
  ]

  
  const changePageNum = pageNumber => {
    getList({ pageNum: pageNumber, pageSize: 10 })
  }

  return (
    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('tel')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="电话"
            />,
          )}
        </Form.Item>
        <Form.Item>
            <Button type="primary" htmlType="submit" >
              查询
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              重置
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              返回
            </Button>
        </Form.Item>
      </Form>
      <Button type="primary" onClick={() => exportCustomer()} style={{ float: 'right', margin: '20px 0', zIndex: 1 }}>
        导出
      </Button>

      <div style={{ margin: '20px 0' }}>
        <AuthButton name="admin.customer.recommend.get" noRight={null}>
          <Radio.Group value={groupStatus} onChange={radioButtonHandleSizeChange} buttonStyle="solid">
            <Radio.Button value="0">拼团成功</Radio.Button>
            <Radio.Button value="1">进行中</Radio.Button>
            <Radio.Button value="2">拼团失败</Radio.Button>
          </Radio.Group>
        </AuthButton>
      </div>

      {groupStatus === '0' ?
        <Table dataSource={dataSource.records} columns={privateColumns} pagination={{ total: dataSource.total, onChange }} rowKey="customerList" /> :
        <Table dataSource={dataSource.records} columns={publicColumns} pagination={{ total: dataSource.total, onChange }} rowKey="customerList" /> 
      }
       {/* <InviteTable visibleData={gInviteData} />
       <Verifier visibleData={gVerifierData} /> */}
    </>
  );
}

const WrappedBody = Form.create({ name: 'body' })(body);

export default WrappedBody
